@@ -14,7 +14,7 @@ class ConectividadeAppConfig(PluginConfig):
     }
 
     #Base URL path. If not set, the plugin name will be used.
-    base_url = 'conectividade-app'
+    base_url = 'conectividadeapp'
     # Caching config
     caching_config = {}
 
